Author: adsb
Date: 2009-01-18 16:16:02 +0000 (Sun, 18 Jan 2009)
New Revision: 1796

Modified:
   trunk/debian/changelog
   trunk/scripts/mergechanges.sh
Log:
mergechanges: Correct spelling of "parameters". Thanks, Kumar Appaiah.
(Closes: #512164)

Modified: trunk/debian/changelog
===================================================================
--- trunk/debian/changelog      2009-01-16 00:50:02 UTC (rev 1795)
+++ trunk/debian/changelog      2009-01-18 16:16:02 UTC (rev 1796)
@@ -15,6 +15,8 @@
   * debcheckout: Fix a typo and perform some QA on the manpage.
   * debsign: Add further quoting around the use and generation of temporary
     directory names, in case $TMPDIR contains spaces.
+  * mergechanges: Correct spelling of "parameters". Thanks, Kumar Appaiah.
+    (Closes: #512164)
 
   [ James Vega ]
   * bts: Document correspondent and affects keys for select command.

Modified: trunk/scripts/mergechanges.sh
===================================================================
--- trunk/scripts/mergechanges.sh       2009-01-16 00:50:02 UTC (rev 1795)
+++ trunk/scripts/mergechanges.sh       2009-01-18 16:16:02 UTC (rev 1796)
@@ -69,9 +69,9 @@
     esac
 done
 
 # Sanity check #0: Do we have enough paramaters?
 if [ $# -lt 2 ]; then
-    echo "Not enough paramaters." >&2
+    echo "Not enough parameters." >&2
     echo "Usage: mergechanges [--help|--version] [-f] <file1> <file2> 
[<file...>]" >&2
     exit 1
@@ -69,9 +69,9 @@
 done
 
-# Sanity check #0: Do we have enough paramaters?
+# Sanity check #0: Do we have enough parameters?
 if [ $# -lt 2 ]; then
 fi



-- 
To unsubscribe, send mail to [email protected].

Reply via email to